@@ -1,6 +1,6 @@
 /* valaccodeblock.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -32,7 +32,7 @@ struct _ValaCCodeBlockPrivate {
 #define VALA_CCODE_BLOCK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_BLOCK, ValaCCodeBlockPrivate))
 enum  {
 	VALA_CCODE_BLOCK_DUMMY_PROPERTY,
-	VALA_CCODE_BLOCK_SUPPRESS_NEWLINE,
+	VALA_CCODE_BLOCK_SUPPRESS_NEWLINE
 };
 static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_block_parent_class = NULL;
@@ -64,15 +64,31 @@ void vala_ccode_block_add_statement (ValaCCodeBlock* self, ValaCCodeNode* statem
 
 static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeBlock * self = VALA_CCODE_BLOCK (base);
+	ValaCCodeBlock * self;
+	self = VALA_CCODE_BLOCK (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_begin_block (writer);
 	{
-		GList* __temp0 = NULL;
-		__temp0 = self->priv->statements;
+		GList* __temp0;
 		GList* statement_it;
+		__temp0 = NULL;
+		__temp0 = self->priv->statements;
 		for (statement_it = __temp0; statement_it != NULL; statement_it = statement_it->next) {
-			ValaCCodeNode* statement = statement_it->data;
+			ValaCCodeNode* statement;
+			statement = statement_it->data;
+			{
+				vala_ccode_node_write_declaration (statement, writer);
+			}
+		}
+	}
+	{
+		GList* __temp1;
+		GList* statement_it;
+		__temp1 = NULL;
+		__temp1 = self->priv->statements;
+		for (statement_it = __temp1; statement_it != NULL; statement_it = statement_it->next) {
+			ValaCCodeNode* statement;
+			statement = statement_it->data;
 			{
 				vala_ccode_node_write (statement, writer);
 			}
@@ -101,7 +117,8 @@ void vala_ccode_block_set_suppress_newline (ValaCCodeBlock* self, gboolean value
 
 static void vala_ccode_block_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeBlock * self = VALA_CCODE_BLOCK (object);
+	ValaCCodeBlock * self;
+	self = VALA_CCODE_BLOCK (object);
 	switch (property_id) {
 		case VALA_CCODE_BLOCK_SUPPRESS_NEWLINE:
 		g_value_set_boolean (value, vala_ccode_block_get_suppress_newline (self));
@@ -112,7 +129,8 @@ static void vala_ccode_block_get_property (GObject * object, guint property_id,
 
 static void vala_ccode_block_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeBlock * self = VALA_CCODE_BLOCK (object);
+	ValaCCodeBlock * self;
+	self = VALA_CCODE_BLOCK (object);
 	switch (property_id) {
 		case VALA_CCODE_BLOCK_SUPPRESS_NEWLINE:
 		vala_ccode_block_set_suppress_newline (self, g_value_get_boolean (value));
@@ -141,10 +159,11 @@ static void vala_ccode_block_init (ValaCCodeBlock * self)
 
 static void vala_ccode_block_dispose (GObject * obj)
 {
-	ValaCCodeBlock * self = VALA_CCODE_BLOCK (obj);
-	(self->priv->statements == NULL ? NULL : (self->priv->statements = (g_list_foreach (self->priv->statements, (GFunc) g_object_unref, NULL), g_list_free (self->priv->statements), NULL)));
+	ValaCCodeBlock * self;
 	ValaCCodeBlockClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_BLOCK (obj);
+	(self->priv->statements == NULL ? NULL : (self->priv->statements = (g_list_foreach (self->priv->statements, (GFunc) g_object_unref, NULL), g_list_free (self->priv->statements), NULL)));
 	klass = VALA_CCODE_BLOCK_CLASS (g_type_class_peek (VALA_TYPE_CCODE_BLOCK));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
