@@ -1,6 +1,6 @@
 /* valaccodenode.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -32,8 +32,9 @@ struct _ValaCCodeNodePrivate {
 #define VALA_CCODE_NODE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_NODE, ValaCCodeNodePrivate))
 enum  {
 	VALA_CCODE_NODE_DUMMY_PROPERTY,
-	VALA_CCODE_NODE_LINE,
+	VALA_CCODE_NODE_LINE
 };
+static void vala_ccode_node_real_write_declaration (ValaCCodeNode* self, ValaCCodeWriter* writer);
 static gpointer vala_ccode_node_parent_class = NULL;
 static void vala_ccode_node_dispose (GObject * obj);
 
@@ -44,6 +45,25 @@ void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer)
 }
 
 
+/**
+ * Writes declaration for this code node with the specified C code
+ * writer if necessary.
+ *
+ * @param writer a C code writer
+ */
+static void vala_ccode_node_real_write_declaration (ValaCCodeNode* self, ValaCCodeWriter* writer)
+{
+	g_return_if_fail (VALA_IS_CCODE_NODE (self));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+}
+
+
+void vala_ccode_node_write_declaration (ValaCCodeNode* self, ValaCCodeWriter* writer)
+{
+	VALA_CCODE_NODE_GET_CLASS (self)->write_declaration (self, writer);
+}
+
+
 ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self)
 {
 	g_return_val_if_fail (VALA_IS_CCODE_NODE (self), NULL);
@@ -53,16 +73,19 @@ ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self)
 
 void vala_ccode_node_set_line (ValaCCodeNode* self, ValaCCodeLineDirective* value)
 {
+	ValaCCodeLineDirective* __temp2;
+	ValaCCodeLineDirective* __temp1;
 	g_return_if_fail (VALA_IS_CCODE_NODE (self));
-	ValaCCodeLineDirective* __temp2 = NULL;
-	ValaCCodeLineDirective* __temp1 = NULL;
+	__temp2 = NULL;
+	__temp1 = NULL;
 	self->priv->_line = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_line == NULL ? NULL : (self->priv->_line = (g_object_unref (self->priv->_line), NULL))), __temp2);
 }
 
 
 static void vala_ccode_node_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeNode * self = VALA_CCODE_NODE (object);
+	ValaCCodeNode * self;
+	self = VALA_CCODE_NODE (object);
 	switch (property_id) {
 		case VALA_CCODE_NODE_LINE:
 		g_value_set_object (value, vala_ccode_node_get_line (self));
@@ -73,7 +96,8 @@ static void vala_ccode_node_get_property (GObject * object, guint property_id, G
 
 static void vala_ccode_node_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeNode * self = VALA_CCODE_NODE (object);
+	ValaCCodeNode * self;
+	self = VALA_CCODE_NODE (object);
 	switch (property_id) {
 		case VALA_CCODE_NODE_LINE:
 		vala_ccode_node_set_line (self, g_value_get_object (value));
@@ -89,6 +113,7 @@ static void vala_ccode_node_class_init (ValaCCodeNodeClass * klass)
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_node_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_node_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_node_dispose;
+	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_node_real_write_declaration;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_NODE_LINE, g_param_spec_object ("line", "foo", "bar", VALA_TYPE_CCODE_LINE_DIRECTIVE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -101,10 +126,11 @@ static void vala_ccode_node_init (ValaCCodeNode * self)
 
 static void vala_ccode_node_dispose (GObject * obj)
 {
-	ValaCCodeNode * self = VALA_CCODE_NODE (obj);
-	(self->priv->_line == NULL ? NULL : (self->priv->_line = (g_object_unref (self->priv->_line), NULL)));
+	ValaCCodeNode * self;
 	ValaCCodeNodeClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_NODE (obj);
+	(self->priv->_line == NULL ? NULL : (self->priv->_line = (g_object_unref (self->priv->_line), NULL)));
 	klass = VALA_CCODE_NODE_CLASS (g_type_class_peek (VALA_TYPE_CCODE_NODE));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
