@@ -70,12 +70,12 @@ enum  {
 	VALA_CLASS_HAS_PRIVATE_FIELDS,
 	VALA_CLASS_DEFAULT_CONSTRUCTION_METHOD,
 	VALA_CLASS_CONSTRUCTOR,
-	VALA_CLASS_DESTRUCTOR,
+	VALA_CLASS_DESTRUCTOR
 };
 static void vala_class_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_class_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_class_real_get_cname (ValaDataType* base, gboolean const_type);
 static char* vala_class_get_lower_case_csuffix (ValaClass* self);
-static void vala_class_set_lower_case_csuffix (ValaClass* self, const char* csuffix);
 static char* vala_class_real_get_lower_case_cname (ValaDataType* base, const char* infix);
 static char* vala_class_real_get_lower_case_cprefix (ValaDataType* base);
 static char* vala_class_real_get_upper_case_cname (ValaDataType* base, const char* infix);
@@ -103,13 +103,16 @@ static void vala_class_dispose (GObject * obj);
  */
 ValaClass* vala_class_new (const char* _name, ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaClass * self;
 	g_return_val_if_fail (_name != NULL, NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaClass * self = g_object_newv (VALA_TYPE_CLASS, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CLASS, __params_it - __params, __params);
 	return self;
 }
 
@@ -245,11 +248,13 @@ void vala_class_add_property (ValaClass* self, ValaProperty* prop, gboolean no_f
 	g_return_if_fail (VALA_IS_PROPERTY (prop));
 	self->priv->properties = g_list_append (self->priv->properties, g_object_ref (prop));
 	if (!no_field && vala_property_get_set_accessor (prop) != NULL && vala_property_accessor_get_body (vala_property_get_set_accessor (prop)) == NULL && vala_code_node_get_source_reference (VALA_CODE_NODE (self)) != NULL && !vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))) {
+		ValaTypeReference* field_type;
+		ValaField* f;
 		/* automatic property accessor body generation */
-		ValaTypeReference* field_type = vala_type_reference_copy (vala_property_get_type_reference (prop));
+		field_type = vala_type_reference_copy (vala_property_get_type_reference (prop));
 		/* non_null fields not yet supported due to initialization issues*/
 		(vala_type_reference_set_non_null (field_type, FALSE), vala_type_reference_get_non_null (field_type));
-		ValaField* f = vala_field_new (g_strdup_printf ("_%s", vala_property_get_name (prop)), field_type, NULL, vala_code_node_get_source_reference (VALA_CODE_NODE (prop)));
+		f = vala_field_new (g_strdup_printf ("_%s", vala_property_get_name (prop)), field_type, NULL, vala_code_node_get_source_reference (VALA_CODE_NODE (prop)));
 		f->access = VALA_MEMBER_ACCESSIBILITY_PRIVATE;
 		vala_class_add_field (self, f);
 		(field_type = (g_object_unref (field_type), NULL));
@@ -297,81 +302,104 @@ GList* vala_class_get_signals (ValaClass* self)
 
 static void vala_class_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaClass * self = VALA_CLASS (base);
+	ValaClass * self;
+	self = VALA_CLASS (base);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_visitor_visit_class (visitor, self);
+}
+
+
+static void vala_class_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
+{
+	ValaClass * self;
+	self = VALA_CLASS (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	vala_code_visitor_visit_begin_class (visitor, self);
 	{
-		GList* __temp6 = NULL;
-		__temp6 = self->priv->base_types;
+		GList* __temp6;
 		GList* type_it;
+		__temp6 = NULL;
+		__temp6 = self->priv->base_types;
 		for (type_it = __temp6; type_it != NULL; type_it = type_it->next) {
-			ValaTypeReference* type = type_it->data;
+			ValaTypeReference* type;
+			type = type_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (type), visitor);
 			}
 		}
 	}
 	{
-		GList* __temp7 = NULL;
-		__temp7 = self->priv->type_parameters;
+		GList* __temp7;
 		GList* p_it;
+		__temp7 = NULL;
+		__temp7 = self->priv->type_parameters;
 		for (p_it = __temp7; p_it != NULL; p_it = p_it->next) {
-			ValaTypeParameter* p = p_it->data;
+			ValaTypeParameter* p;
+			p = p_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (p), visitor);
 			}
 		}
 	}
 	{
-		GList* __temp8 = NULL;
-		__temp8 = self->priv->fields;
+		GList* __temp8;
 		GList* f_it;
+		__temp8 = NULL;
+		__temp8 = self->priv->fields;
 		for (f_it = __temp8; f_it != NULL; f_it = f_it->next) {
-			ValaField* f = f_it->data;
+			ValaField* f;
+			f = f_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (f), visitor);
 			}
 		}
 	}
 	{
-		GList* __temp9 = NULL;
-		__temp9 = self->priv->constants;
+		GList* __temp9;
 		GList* c_it;
+		__temp9 = NULL;
+		__temp9 = self->priv->constants;
 		for (c_it = __temp9; c_it != NULL; c_it = c_it->next) {
-			ValaConstant* c = c_it->data;
+			ValaConstant* c;
+			c = c_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (c), visitor);
 			}
 		}
 	}
 	{
-		GList* __temp10 = NULL;
-		__temp10 = self->priv->methods;
+		GList* __temp10;
 		GList* m_it;
+		__temp10 = NULL;
+		__temp10 = self->priv->methods;
 		for (m_it = __temp10; m_it != NULL; m_it = m_it->next) {
-			ValaMethod* m = m_it->data;
+			ValaMethod* m;
+			m = m_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (m), visitor);
 			}
 		}
 	}
 	{
-		GList* __temp11 = NULL;
-		__temp11 = self->priv->properties;
+		GList* __temp11;
 		GList* prop_it;
+		__temp11 = NULL;
+		__temp11 = self->priv->properties;
 		for (prop_it = __temp11; prop_it != NULL; prop_it = prop_it->next) {
-			ValaProperty* prop = prop_it->data;
+			ValaProperty* prop;
+			prop = prop_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (prop), visitor);
 			}
 		}
 	}
 	{
-		GList* __temp12 = NULL;
-		__temp12 = self->priv->signals;
+		GList* __temp12;
 		GList* sig_it;
+		__temp12 = NULL;
+		__temp12 = self->priv->signals;
 		for (sig_it = __temp12; sig_it != NULL; sig_it = sig_it->next) {
-			ValaSignal* sig = sig_it->data;
+			ValaSignal* sig;
+			sig = sig_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (sig), visitor);
 			}
@@ -383,20 +411,23 @@ static void vala_class_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor
 	if (vala_class_get_destructor (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_class_get_destructor (self)), visitor);
 	}
-	vala_code_visitor_visit_end_class (visitor, self);
 }
 
 
 static char* vala_class_real_get_cname (ValaDataType* base, gboolean const_type)
 {
-	ValaClass * self = VALA_CLASS (base);
+	ValaClass * self;
+	const char* __temp15;
+	self = VALA_CLASS (base);
 	if (self->priv->cname == NULL) {
-		char* __temp14 = NULL;
-		char* __temp13 = NULL;
+		char* __temp14;
+		char* __temp13;
+		__temp14 = NULL;
+		__temp13 = NULL;
 		self->priv->cname = (__temp14 = g_strdup_printf ("%s%s", (__temp13 = vala_namespace_get_cprefix (VALA_DATA_TYPE (self)->namespace)), vala_data_type_get_name (VALA_DATA_TYPE (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp14);
 		(__temp13 = (g_free (__temp13), NULL));
 	}
-	const char* __temp15 = NULL;
+	__temp15 = NULL;
 	return (__temp15 = self->priv->cname, (__temp15 == NULL ? NULL : g_strdup (__temp15)));
 }
 
@@ -408,68 +439,73 @@ static char* vala_class_real_get_cname (ValaDataType* base, gboolean const_type)
  */
 void vala_class_set_cname (ValaClass* self, const char* cname)
 {
+	char* __temp17;
 	g_return_if_fail (VALA_IS_CLASS (self));
 	g_return_if_fail (cname != NULL);
-	char* __temp17 = NULL;
+	__temp17 = NULL;
 	self->priv->cname = (__temp17 = g_strdup (cname), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp17);
 }
 
 
 static char* vala_class_get_lower_case_csuffix (ValaClass* self)
 {
+	const char* __temp19;
 	g_return_val_if_fail (VALA_IS_CLASS (self), NULL);
 	if (self->priv->lower_case_csuffix == NULL) {
-		char* __temp18 = NULL;
+		char* __temp18;
+		__temp18 = NULL;
 		self->priv->lower_case_csuffix = (__temp18 = vala_namespace_camel_case_to_lower_case (vala_data_type_get_name (VALA_DATA_TYPE (self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), __temp18);
 	}
-	const char* __temp19 = NULL;
+	__temp19 = NULL;
 	return (__temp19 = self->priv->lower_case_csuffix, (__temp19 == NULL ? NULL : g_strdup (__temp19)));
 }
 
 
-static void vala_class_set_lower_case_csuffix (ValaClass* self, const char* csuffix)
-{
-	g_return_if_fail (VALA_IS_CLASS (self));
-	g_return_if_fail (csuffix != NULL);
-	char* __temp21 = NULL;
-	self->priv->lower_case_csuffix = (__temp21 = g_strdup (csuffix), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), __temp21);
-}
-
-
 static char* vala_class_real_get_lower_case_cname (ValaDataType* base, const char* infix)
 {
-	ValaClass * self = VALA_CLASS (base);
+	ValaClass * self;
+	char* __temp22;
+	char* __temp21;
+	char* __temp23;
+	self = VALA_CLASS (base);
 	if (infix == NULL) {
 		infix = "";
 	}
-	char* __temp23 = NULL;
-	char* __temp22 = NULL;
-	char* __temp24 = NULL;
-	return (__temp24 = g_strdup_printf ("%s%s%s", (__temp22 = vala_namespace_get_lower_case_cprefix (VALA_DATA_TYPE (self)->namespace)), infix, (__temp23 = vala_class_get_lower_case_csuffix (self))), (__temp23 = (g_free (__temp23), NULL)), (__temp22 = (g_free (__temp22), NULL)), __temp24);
+	__temp22 = NULL;
+	__temp21 = NULL;
+	__temp23 = NULL;
+	return (__temp23 = g_strdup_printf ("%s%s%s", (__temp21 = vala_namespace_get_lower_case_cprefix (VALA_DATA_TYPE (self)->namespace)), infix, (__temp22 = vala_class_get_lower_case_csuffix (self))), (__temp22 = (g_free (__temp22), NULL)), (__temp21 = (g_free (__temp21), NULL)), __temp23);
 }
 
 
 static char* vala_class_real_get_lower_case_cprefix (ValaDataType* base)
 {
-	ValaClass * self = VALA_CLASS (base);
-	char* __temp26 = NULL;
-	char* __temp27 = NULL;
-	return (__temp27 = g_strdup_printf ("%s_", (__temp26 = vala_data_type_get_lower_case_cname (VALA_DATA_TYPE (self), NULL))), (__temp26 = (g_free (__temp26), NULL)), __temp27);
+	ValaClass * self;
+	char* __temp25;
+	char* __temp26;
+	self = VALA_CLASS (base);
+	__temp25 = NULL;
+	__temp26 = NULL;
+	return (__temp26 = g_strdup_printf ("%s_", (__temp25 = vala_data_type_get_lower_case_cname (VALA_DATA_TYPE (self), NULL))), (__temp25 = (g_free (__temp25), NULL)), __temp26);
 }
 
 
 static char* vala_class_real_get_upper_case_cname (ValaDataType* base, const char* infix)
 {
-	ValaClass * self = VALA_CLASS (base);
-	char* __temp29 = NULL;
-	char* __temp30 = NULL;
-	return (__temp30 = g_utf8_strup ((__temp29 = vala_data_type_get_lower_case_cname (VALA_DATA_TYPE (self), infix)), -1), (__temp29 = (g_free (__temp29), NULL)), __temp30);
+	ValaClass * self;
+	char* __temp28;
+	char* __temp29;
+	self = VALA_CLASS (base);
+	__temp28 = NULL;
+	__temp29 = NULL;
+	return (__temp29 = g_utf8_strup ((__temp28 = vala_data_type_get_lower_case_cname (VALA_DATA_TYPE (self), infix)), -1), (__temp28 = (g_free (__temp28), NULL)), __temp29);
 }
 
 
 static gboolean vala_class_real_is_reference_type (ValaDataType* base)
 {
-	ValaClass * self = VALA_CLASS (base);
+	ValaClass * self;
+	self = VALA_CLASS (base);
 	return TRUE;
 }
 
@@ -479,23 +515,27 @@ static void vala_class_process_ccode_attribute (ValaClass* self, ValaAttribute*
 	g_return_if_fail (VALA_IS_CLASS (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
-		char* __temp33 = NULL;
-		vala_class_set_cname (self, (__temp33 = vala_attribute_get_string (a, "cname")));
-		(__temp33 = (g_free (__temp33), NULL));
+		char* __temp32;
+		__temp32 = NULL;
+		vala_class_set_cname (self, (__temp32 = vala_attribute_get_string (a, "cname")));
+		(__temp32 = (g_free (__temp32), NULL));
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
-		char* val = vala_attribute_get_string (a, "cheader_filename");
+		char* val;
+		val = vala_attribute_get_string (a, "cheader_filename");
 		{
-			char** __temp34 = NULL;
-			__temp34 = g_strsplit (val, ",", 0);
+			char** __temp33;
 			char** filename_it;
-			for (filename_it = __temp34; *filename_it != NULL; filename_it = filename_it + 1) {
-				char* filename = *filename_it;
+			__temp33 = NULL;
+			__temp33 = g_strsplit (val, ",", 0);
+			for (filename_it = __temp33; *filename_it != NULL; filename_it = filename_it + 1) {
+				char* filename;
+				filename = *filename_it;
 				{
 					vala_data_type_add_cheader_filename (VALA_DATA_TYPE (self), filename);
 				}
 			}
-			(__temp34 = (g_free (__temp34), NULL));
+			(__temp33 = (g_free (__temp33), NULL));
 		}
 		(val = (g_free (val), NULL));
 	}
@@ -509,11 +549,13 @@ void vala_class_process_attributes (ValaClass* self)
 {
 	g_return_if_fail (VALA_IS_CLASS (self));
 	{
-		GList* __temp35 = NULL;
-		__temp35 = VALA_CODE_NODE (self)->attributes;
+		GList* __temp34;
 		GList* a_it;
-		for (a_it = __temp35; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* a = a_it->data;
+		__temp34 = NULL;
+		__temp34 = VALA_CODE_NODE (self)->attributes;
+		for (a_it = __temp34; a_it != NULL; a_it = a_it->next) {
+			ValaAttribute* a;
+			a = a_it->data;
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_class_process_ccode_attribute (self, a);
@@ -526,68 +568,80 @@ void vala_class_process_attributes (ValaClass* self)
 
 static char* vala_class_real_get_type_id (ValaDataType* base)
 {
-	ValaClass * self = VALA_CLASS (base);
+	ValaClass * self;
+	const char* __temp36;
+	self = VALA_CLASS (base);
 	if (self->priv->type_id == NULL) {
-		char* __temp36 = NULL;
-		self->priv->type_id = (__temp36 = vala_data_type_get_upper_case_cname (VALA_DATA_TYPE (self), "TYPE_"), (self->priv->type_id = (g_free (self->priv->type_id), NULL)), __temp36);
+		char* __temp35;
+		__temp35 = NULL;
+		self->priv->type_id = (__temp35 = vala_data_type_get_upper_case_cname (VALA_DATA_TYPE (self), "TYPE_"), (self->priv->type_id = (g_free (self->priv->type_id), NULL)), __temp35);
 	}
-	const char* __temp37 = NULL;
-	return (__temp37 = self->priv->type_id, (__temp37 == NULL ? NULL : g_strdup (__temp37)));
+	__temp36 = NULL;
+	return (__temp36 = self->priv->type_id, (__temp36 == NULL ? NULL : g_strdup (__temp36)));
 }
 
 
 static char* vala_class_real_get_marshaller_type_name (ValaDataType* base)
 {
-	ValaClass * self = VALA_CLASS (base);
+	ValaClass * self;
+	self = VALA_CLASS (base);
 	return g_strdup ("OBJECT");
 }
 
 
 static char* vala_class_real_get_get_value_function (ValaDataType* base)
 {
-	ValaClass * self = VALA_CLASS (base);
+	ValaClass * self;
+	self = VALA_CLASS (base);
 	return g_strdup ("g_value_get_object");
 }
 
 
 static char* vala_class_real_get_set_value_function (ValaDataType* base)
 {
-	ValaClass * self = VALA_CLASS (base);
+	ValaClass * self;
+	self = VALA_CLASS (base);
 	return g_strdup ("g_value_set_object");
 }
 
 
 static gboolean vala_class_real_is_reference_counting (ValaDataType* base)
 {
-	ValaClass * self = VALA_CLASS (base);
+	ValaClass * self;
+	self = VALA_CLASS (base);
 	return TRUE;
 }
 
 
 static char* vala_class_real_get_ref_function (ValaDataType* base)
 {
-	ValaClass * self = VALA_CLASS (base);
+	ValaClass * self;
+	self = VALA_CLASS (base);
 	return g_strdup ("g_object_ref");
 }
 
 
 static char* vala_class_real_get_unref_function (ValaDataType* base)
 {
-	ValaClass * self = VALA_CLASS (base);
+	ValaClass * self;
+	self = VALA_CLASS (base);
 	return g_strdup ("g_object_unref");
 }
 
 
 static gboolean vala_class_real_is_subtype_of (ValaDataType* base, ValaDataType* t)
 {
-	ValaClass * self = VALA_CLASS (base);
+	ValaClass * self;
+	self = VALA_CLASS (base);
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (t), FALSE);
 	{
-		GList* __temp46 = NULL;
-		__temp46 = self->priv->base_types;
+		GList* __temp45;
 		GList* base_type_it;
-		for (base_type_it = __temp46; base_type_it != NULL; base_type_it = base_type_it->next) {
-			ValaTypeReference* base_type = base_type_it->data;
+		__temp45 = NULL;
+		__temp45 = self->priv->base_types;
+		for (base_type_it = __temp45; base_type_it != NULL; base_type_it = base_type_it->next) {
+			ValaTypeReference* base_type;
+			base_type = base_type_it->data;
 			{
 				if (vala_type_reference_get_data_type (base_type) == t || vala_data_type_is_subtype_of (vala_type_reference_get_data_type (base_type), t)) {
 					return TRUE;
@@ -601,15 +655,19 @@ static gboolean vala_class_real_is_subtype_of (ValaDataType* base, ValaDataType*
 
 static gint vala_class_real_get_type_parameter_index (ValaDataType* base, const char* name)
 {
-	ValaClass * self = VALA_CLASS (base);
+	ValaClass * self;
+	gint i;
+	self = VALA_CLASS (base);
 	g_return_val_if_fail (name != NULL, 0);
-	gint i = 0;
+	i = 0;
 	{
-		GList* __temp49 = NULL;
-		__temp49 = self->priv->type_parameters;
+		GList* __temp48;
 		GList* parameter_it;
-		for (parameter_it = __temp49; parameter_it != NULL; parameter_it = parameter_it->next) {
-			ValaTypeParameter* parameter = parameter_it->data;
+		__temp48 = NULL;
+		__temp48 = self->priv->type_parameters;
+		for (parameter_it = __temp48; parameter_it != NULL; parameter_it = parameter_it->next) {
+			ValaTypeParameter* parameter;
+			parameter = parameter_it->data;
 			{
 				if (g_utf8_collate (vala_type_parameter_get_name (parameter), name) == 0) {
 					return i;
@@ -631,10 +689,12 @@ ValaClass* vala_class_get_base_class (ValaClass* self)
 
 void vala_class_set_base_class (ValaClass* self, ValaClass* value)
 {
+	ValaClass* __temp52;
+	ValaClass* __temp51;
 	g_return_if_fail (VALA_IS_CLASS (self));
-	ValaClass* __temp53 = NULL;
-	ValaClass* __temp52 = NULL;
-	self->priv->_base_class = (__temp53 = (__temp52 = value, (__temp52 == NULL ? NULL : g_object_ref (__temp52))), (self->priv->_base_class == NULL ? NULL : (self->priv->_base_class = (g_object_unref (self->priv->_base_class), NULL))), __temp53);
+	__temp52 = NULL;
+	__temp51 = NULL;
+	self->priv->_base_class = (__temp52 = (__temp51 = value, (__temp51 == NULL ? NULL : g_object_ref (__temp51))), (self->priv->_base_class == NULL ? NULL : (self->priv->_base_class = (g_object_unref (self->priv->_base_class), NULL))), __temp52);
 }
 
 
@@ -682,10 +742,12 @@ ValaMethod* vala_class_get_default_construction_method (ValaClass* self)
 
 void vala_class_set_default_construction_method (ValaClass* self, ValaMethod* value)
 {
+	ValaMethod* __temp58;
+	ValaMethod* __temp57;
 	g_return_if_fail (VALA_IS_CLASS (self));
-	ValaMethod* __temp59 = NULL;
-	ValaMethod* __temp58 = NULL;
-	self->priv->_default_construction_method = (__temp59 = (__temp58 = value, (__temp58 == NULL ? NULL : g_object_ref (__temp58))), (self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL))), __temp59);
+	__temp58 = NULL;
+	__temp57 = NULL;
+	self->priv->_default_construction_method = (__temp58 = (__temp57 = value, (__temp57 == NULL ? NULL : g_object_ref (__temp57))), (self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL))), __temp58);
 }
 
 
@@ -698,10 +760,12 @@ ValaConstructor* vala_class_get_constructor (ValaClass* self)
 
 void vala_class_set_constructor (ValaClass* self, ValaConstructor* value)
 {
+	ValaConstructor* __temp61;
+	ValaConstructor* __temp60;
 	g_return_if_fail (VALA_IS_CLASS (self));
-	ValaConstructor* __temp62 = NULL;
-	ValaConstructor* __temp61 = NULL;
-	self->priv->_constructor = (__temp62 = (__temp61 = value, (__temp61 == NULL ? NULL : g_object_ref (__temp61))), (self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (g_object_unref (self->priv->_constructor), NULL))), __temp62);
+	__temp61 = NULL;
+	__temp60 = NULL;
+	self->priv->_constructor = (__temp61 = (__temp60 = value, (__temp60 == NULL ? NULL : g_object_ref (__temp60))), (self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (g_object_unref (self->priv->_constructor), NULL))), __temp61);
 }
 
 
@@ -714,16 +778,19 @@ ValaDestructor* vala_class_get_destructor (ValaClass* self)
 
 void vala_class_set_destructor (ValaClass* self, ValaDestructor* value)
 {
+	ValaDestructor* __temp64;
+	ValaDestructor* __temp63;
 	g_return_if_fail (VALA_IS_CLASS (self));
-	ValaDestructor* __temp65 = NULL;
-	ValaDestructor* __temp64 = NULL;
-	self->priv->_destructor = (__temp65 = (__temp64 = value, (__temp64 == NULL ? NULL : g_object_ref (__temp64))), (self->priv->_destructor == NULL ? NULL : (self->priv->_destructor = (g_object_unref (self->priv->_destructor), NULL))), __temp65);
+	__temp64 = NULL;
+	__temp63 = NULL;
+	self->priv->_destructor = (__temp64 = (__temp63 = value, (__temp63 == NULL ? NULL : g_object_ref (__temp63))), (self->priv->_destructor == NULL ? NULL : (self->priv->_destructor = (g_object_unref (self->priv->_destructor), NULL))), __temp64);
 }
 
 
 static void vala_class_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaClass * self = VALA_CLASS (object);
+	ValaClass * self;
+	self = VALA_CLASS (object);
 	switch (property_id) {
 		case VALA_CLASS_BASE_CLASS:
 		g_value_set_object (value, vala_class_get_base_class (self));
@@ -752,7 +819,8 @@ static void vala_class_get_property (GObject * object, guint property_id, GValue
 
 static void vala_class_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaClass * self = VALA_CLASS (object);
+	ValaClass * self;
+	self = VALA_CLASS (object);
 	switch (property_id) {
 		case VALA_CLASS_BASE_CLASS:
 		vala_class_set_base_class (self, g_value_get_object (value));
@@ -784,6 +852,7 @@ static void vala_class_class_init (ValaClassClass * klass)
 	G_OBJECT_CLASS (klass)->set_property = vala_class_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_class_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_class_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_class_real_accept_children;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_class_real_get_cname;
 	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cname = vala_class_real_get_lower_case_cname;
 	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cprefix = vala_class_real_get_lower_case_cprefix;
@@ -816,7 +885,10 @@ static void vala_class_init (ValaClass * self)
 
 static void vala_class_dispose (GObject * obj)
 {
-	ValaClass * self = VALA_CLASS (obj);
+	ValaClass * self;
+	ValaClassClass * klass;
+	GObjectClass * parent_class;
+	self = VALA_CLASS (obj);
 	(self->priv->_base_class == NULL ? NULL : (self->priv->_base_class = (g_object_unref (self->priv->_base_class), NULL)));
 	(self->priv->cname = (g_free (self->priv->cname), NULL));
 	(self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL));
@@ -831,8 +903,6 @@ static void vala_class_dispose (GObject * obj)
 	(self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL)));
 	(self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (g_object_unref (self->priv->_constructor), NULL)));
 	(self->priv->_destructor == NULL ? NULL : (self->priv->_destructor = (g_object_unref (self->priv->_destructor), NULL)));
-	ValaClassClass * klass;
-	GObjectClass * parent_class;
 	klass = VALA_CLASS_CLASS (g_type_class_peek (VALA_TYPE_CLASS));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
