@@ -86,6 +86,7 @@
 #include <vala/valabaseaccess.h>
 #include <vala/valapostfixexpression.h>
 #include <vala/valaobjectcreationexpression.h>
+#include <vala/valasizeofexpression.h>
 #include <vala/valatypeofexpression.h>
 #include <vala/valaunaryexpression.h>
 #include <vala/valacastexpression.h>
@@ -99,48 +100,30 @@
 #include <vala/valaassignment.h>
 #include <vala/valaexpression.h>
 
-struct _ValaCodeVisitorPrivate {
-};
-#define VALA_CODE_VISITOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CODE_VISITOR, ValaCodeVisitorPrivate))
 enum  {
-	VALA_CODE_VISITOR_DUMMY_PROPERTY,
+	VALA_CODE_VISITOR_DUMMY_PROPERTY
 };
-static void vala_code_visitor_real_visit_begin_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file);
-static void vala_code_visitor_real_visit_end_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file);
-static void vala_code_visitor_real_visit_begin_namespace (ValaCodeVisitor* self, ValaNamespace* ns);
-static void vala_code_visitor_real_visit_end_namespace (ValaCodeVisitor* self, ValaNamespace* ns);
-static void vala_code_visitor_real_visit_begin_class (ValaCodeVisitor* self, ValaClass* cl);
-static void vala_code_visitor_real_visit_end_class (ValaCodeVisitor* self, ValaClass* cl);
-static void vala_code_visitor_real_visit_begin_struct (ValaCodeVisitor* self, ValaStruct* st);
-static void vala_code_visitor_real_visit_end_struct (ValaCodeVisitor* self, ValaStruct* st);
-static void vala_code_visitor_real_visit_begin_interface (ValaCodeVisitor* self, ValaInterface* iface);
-static void vala_code_visitor_real_visit_end_interface (ValaCodeVisitor* self, ValaInterface* iface);
-static void vala_code_visitor_real_visit_begin_enum (ValaCodeVisitor* self, ValaEnum* en);
-static void vala_code_visitor_real_visit_end_enum (ValaCodeVisitor* self, ValaEnum* en);
+static void vala_code_visitor_real_visit_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file);
+static void vala_code_visitor_real_visit_namespace (ValaCodeVisitor* self, ValaNamespace* ns);
+static void vala_code_visitor_real_visit_class (ValaCodeVisitor* self, ValaClass* cl);
+static void vala_code_visitor_real_visit_struct (ValaCodeVisitor* self, ValaStruct* st);
+static void vala_code_visitor_real_visit_interface (ValaCodeVisitor* self, ValaInterface* iface);
+static void vala_code_visitor_real_visit_enum (ValaCodeVisitor* self, ValaEnum* en);
 static void vala_code_visitor_real_visit_enum_value (ValaCodeVisitor* self, ValaEnumValue* ev);
-static void vala_code_visitor_real_visit_begin_flags (ValaCodeVisitor* self, ValaFlags* fl);
-static void vala_code_visitor_real_visit_end_flags (ValaCodeVisitor* self, ValaFlags* fl);
+static void vala_code_visitor_real_visit_flags (ValaCodeVisitor* self, ValaFlags* fl);
 static void vala_code_visitor_real_visit_flags_value (ValaCodeVisitor* self, ValaFlagsValue* fv);
-static void vala_code_visitor_real_visit_begin_callback (ValaCodeVisitor* self, ValaCallback* cb);
-static void vala_code_visitor_real_visit_end_callback (ValaCodeVisitor* self, ValaCallback* cb);
+static void vala_code_visitor_real_visit_callback (ValaCodeVisitor* self, ValaCallback* cb);
 static void vala_code_visitor_real_visit_member (ValaCodeVisitor* self, ValaMember* m);
 static void vala_code_visitor_real_visit_constant (ValaCodeVisitor* self, ValaConstant* c);
 static void vala_code_visitor_real_visit_field (ValaCodeVisitor* self, ValaField* f);
-static void vala_code_visitor_real_visit_begin_method (ValaCodeVisitor* self, ValaMethod* m);
-static void vala_code_visitor_real_visit_end_method (ValaCodeVisitor* self, ValaMethod* m);
-static void vala_code_visitor_real_visit_begin_creation_method (ValaCodeVisitor* self, ValaCreationMethod* m);
-static void vala_code_visitor_real_visit_end_creation_method (ValaCodeVisitor* self, ValaCreationMethod* m);
+static void vala_code_visitor_real_visit_method (ValaCodeVisitor* self, ValaMethod* m);
+static void vala_code_visitor_real_visit_creation_method (ValaCodeVisitor* self, ValaCreationMethod* m);
 static void vala_code_visitor_real_visit_formal_parameter (ValaCodeVisitor* self, ValaFormalParameter* p);
-static void vala_code_visitor_real_visit_begin_property (ValaCodeVisitor* self, ValaProperty* prop);
-static void vala_code_visitor_real_visit_end_property (ValaCodeVisitor* self, ValaProperty* prop);
-static void vala_code_visitor_real_visit_begin_property_accessor (ValaCodeVisitor* self, ValaPropertyAccessor* acc);
-static void vala_code_visitor_real_visit_end_property_accessor (ValaCodeVisitor* self, ValaPropertyAccessor* acc);
-static void vala_code_visitor_real_visit_begin_signal (ValaCodeVisitor* self, ValaSignal* sig);
-static void vala_code_visitor_real_visit_end_signal (ValaCodeVisitor* self, ValaSignal* sig);
-static void vala_code_visitor_real_visit_begin_constructor (ValaCodeVisitor* self, ValaConstructor* c);
-static void vala_code_visitor_real_visit_end_constructor (ValaCodeVisitor* self, ValaConstructor* c);
-static void vala_code_visitor_real_visit_begin_destructor (ValaCodeVisitor* self, ValaDestructor* d);
-static void vala_code_visitor_real_visit_end_destructor (ValaCodeVisitor* self, ValaDestructor* d);
+static void vala_code_visitor_real_visit_property (ValaCodeVisitor* self, ValaProperty* prop);
+static void vala_code_visitor_real_visit_property_accessor (ValaCodeVisitor* self, ValaPropertyAccessor* acc);
+static void vala_code_visitor_real_visit_signal (ValaCodeVisitor* self, ValaSignal* sig);
+static void vala_code_visitor_real_visit_constructor (ValaCodeVisitor* self, ValaConstructor* c);
+static void vala_code_visitor_real_visit_destructor (ValaCodeVisitor* self, ValaDestructor* d);
 static void vala_code_visitor_real_visit_named_argument (ValaCodeVisitor* self, ValaNamedArgument* n);
 static void vala_code_visitor_real_visit_type_parameter (ValaCodeVisitor* self, ValaTypeParameter* p);
 static void vala_code_visitor_real_visit_namespace_reference (ValaCodeVisitor* self, ValaNamespaceReference* ns);
@@ -192,6 +175,7 @@ static void vala_code_visitor_real_visit_base_access (ValaCodeVisitor* self, Val
 static void vala_code_visitor_real_visit_postfix_expression (ValaCodeVisitor* self, ValaPostfixExpression* expr);
 static void vala_code_visitor_real_visit_begin_object_creation_expression (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
 static void vala_code_visitor_real_visit_end_object_creation_expression (ValaCodeVisitor* self, ValaObjectCreationExpression* expr);
+static void vala_code_visitor_real_visit_sizeof_expression (ValaCodeVisitor* self, ValaSizeofExpression* expr);
 static void vala_code_visitor_real_visit_typeof_expression (ValaCodeVisitor* self, ValaTypeofExpression* expr);
 static void vala_code_visitor_real_visit_unary_expression (ValaCodeVisitor* self, ValaUnaryExpression* expr);
 static void vala_code_visitor_real_visit_cast_expression (ValaCodeVisitor* self, ValaCastExpression* expr);
@@ -210,218 +194,110 @@ static gpointer vala_code_visitor_parent_class = NULL;
 
 
 /**
- * Visit operation called at beginning of source files.
+ * Visit operation called for source files.
  *
  * @param source_file a source file
  */
-static void vala_code_visitor_real_visit_begin_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file)
+static void vala_code_visitor_real_visit_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_SOURCE_FILE (source_file));
 }
 
 
-void vala_code_visitor_visit_begin_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file)
+void vala_code_visitor_visit_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_source_file (self, source_file);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_source_file (self, source_file);
 }
 
 
 /**
- * Visit operation called at end of source files.
- *
- * @param source_file a source file
- */
-static void vala_code_visitor_real_visit_end_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_SOURCE_FILE (source_file));
-}
-
-
-void vala_code_visitor_visit_end_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_source_file (self, source_file);
-}
-
-
-/**
- * Visit operation called at beginning of namespaces.
+ * Visit operation called for namespaces.
  *
  * @param ns a namespace
  */
-static void vala_code_visitor_real_visit_begin_namespace (ValaCodeVisitor* self, ValaNamespace* ns)
+static void vala_code_visitor_real_visit_namespace (ValaCodeVisitor* self, ValaNamespace* ns)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_NAMESPACE (ns));
 }
 
 
-void vala_code_visitor_visit_begin_namespace (ValaCodeVisitor* self, ValaNamespace* ns)
+void vala_code_visitor_visit_namespace (ValaCodeVisitor* self, ValaNamespace* ns)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_namespace (self, ns);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_namespace (self, ns);
 }
 
 
 /**
- * Visit operation called at end of namespaces.
- *
- * @param ns a namespace
- */
-static void vala_code_visitor_real_visit_end_namespace (ValaCodeVisitor* self, ValaNamespace* ns)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_NAMESPACE (ns));
-}
-
-
-void vala_code_visitor_visit_end_namespace (ValaCodeVisitor* self, ValaNamespace* ns)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_namespace (self, ns);
-}
-
-
-/**
- * Visit operation called at beginning of classes.
+ * Visit operation called for classes.
  *
  * @param cl a class
  */
-static void vala_code_visitor_real_visit_begin_class (ValaCodeVisitor* self, ValaClass* cl)
+static void vala_code_visitor_real_visit_class (ValaCodeVisitor* self, ValaClass* cl)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_CLASS (cl));
 }
 
 
-void vala_code_visitor_visit_begin_class (ValaCodeVisitor* self, ValaClass* cl)
+void vala_code_visitor_visit_class (ValaCodeVisitor* self, ValaClass* cl)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_class (self, cl);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_class (self, cl);
 }
 
 
 /**
- * Visit operation called at end of classes.
- *
- * @param cl a class
- */
-static void vala_code_visitor_real_visit_end_class (ValaCodeVisitor* self, ValaClass* cl)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_CLASS (cl));
-}
-
-
-void vala_code_visitor_visit_end_class (ValaCodeVisitor* self, ValaClass* cl)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_class (self, cl);
-}
-
-
-/**
- * Visit operation called at beginning of structs.
+ * Visit operation called for structs.
  *
  * @param st a struct
  */
-static void vala_code_visitor_real_visit_begin_struct (ValaCodeVisitor* self, ValaStruct* st)
+static void vala_code_visitor_real_visit_struct (ValaCodeVisitor* self, ValaStruct* st)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_STRUCT (st));
 }
 
 
-void vala_code_visitor_visit_begin_struct (ValaCodeVisitor* self, ValaStruct* st)
+void vala_code_visitor_visit_struct (ValaCodeVisitor* self, ValaStruct* st)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_struct (self, st);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_struct (self, st);
 }
 
 
 /**
- * Visit operation called at end of structs.
- *
- * @param st a struct
- */
-static void vala_code_visitor_real_visit_end_struct (ValaCodeVisitor* self, ValaStruct* st)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_STRUCT (st));
-}
-
-
-void vala_code_visitor_visit_end_struct (ValaCodeVisitor* self, ValaStruct* st)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_struct (self, st);
-}
-
-
-/**
- * Visit operation called at beginning of interfaces.
+ * Visit operation called for interfaces.
  *
  * @param iface an interface
  */
-static void vala_code_visitor_real_visit_begin_interface (ValaCodeVisitor* self, ValaInterface* iface)
+static void vala_code_visitor_real_visit_interface (ValaCodeVisitor* self, ValaInterface* iface)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_INTERFACE (iface));
 }
 
 
-void vala_code_visitor_visit_begin_interface (ValaCodeVisitor* self, ValaInterface* iface)
+void vala_code_visitor_visit_interface (ValaCodeVisitor* self, ValaInterface* iface)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_interface (self, iface);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_interface (self, iface);
 }
 
 
 /**
- * Visit operation called at end of interfaces.
- *
- * @param iface an interface
- */
-static void vala_code_visitor_real_visit_end_interface (ValaCodeVisitor* self, ValaInterface* iface)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_INTERFACE (iface));
-}
-
-
-void vala_code_visitor_visit_end_interface (ValaCodeVisitor* self, ValaInterface* iface)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_interface (self, iface);
-}
-
-
-/**
- * Visit operation called at beginning of enums.
+ * Visit operation called for enums.
  *
  * @param en an enum
  */
-static void vala_code_visitor_real_visit_begin_enum (ValaCodeVisitor* self, ValaEnum* en)
+static void vala_code_visitor_real_visit_enum (ValaCodeVisitor* self, ValaEnum* en)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_ENUM (en));
 }
 
 
-void vala_code_visitor_visit_begin_enum (ValaCodeVisitor* self, ValaEnum* en)
+void vala_code_visitor_visit_enum (ValaCodeVisitor* self, ValaEnum* en)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_enum (self, en);
-}
-
-
-/**
- * Visit operation called at end of enums.
- *
- * @param en an enum
- */
-static void vala_code_visitor_real_visit_end_enum (ValaCodeVisitor* self, ValaEnum* en)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_ENUM (en));
-}
-
-
-void vala_code_visitor_visit_end_enum (ValaCodeVisitor* self, ValaEnum* en)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_enum (self, en);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_enum (self, en);
 }
 
 
@@ -444,38 +320,20 @@ void vala_code_visitor_visit_enum_value (ValaCodeVisitor* self, ValaEnumValue* e
 
 
 /**
- * Visit operation called at beginning of flags.
+ * Visit operation called for flags.
  *
  * @param fl a flags
  */
-static void vala_code_visitor_real_visit_begin_flags (ValaCodeVisitor* self, ValaFlags* fl)
+static void vala_code_visitor_real_visit_flags (ValaCodeVisitor* self, ValaFlags* fl)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_FLAGS (fl));
 }
 
 
-void vala_code_visitor_visit_begin_flags (ValaCodeVisitor* self, ValaFlags* fl)
+void vala_code_visitor_visit_flags (ValaCodeVisitor* self, ValaFlags* fl)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_flags (self, fl);
-}
-
-
-/**
- * Visit operation called at end of flags.
- *
- * @param fl a flags
- */
-static void vala_code_visitor_real_visit_end_flags (ValaCodeVisitor* self, ValaFlags* fl)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_FLAGS (fl));
-}
-
-
-void vala_code_visitor_visit_end_flags (ValaCodeVisitor* self, ValaFlags* fl)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_flags (self, fl);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_flags (self, fl);
 }
 
 
@@ -498,43 +356,25 @@ void vala_code_visitor_visit_flags_value (ValaCodeVisitor* self, ValaFlagsValue*
 
 
 /**
- * Visit operation called at beginning of callbacks.
+ * Visit operation called for callbacks.
  *
  * @param cb a callback
  */
-static void vala_code_visitor_real_visit_begin_callback (ValaCodeVisitor* self, ValaCallback* cb)
+static void vala_code_visitor_real_visit_callback (ValaCodeVisitor* self, ValaCallback* cb)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_CALLBACK (cb));
 }
 
 
-void vala_code_visitor_visit_begin_callback (ValaCodeVisitor* self, ValaCallback* cb)
+void vala_code_visitor_visit_callback (ValaCodeVisitor* self, ValaCallback* cb)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_callback (self, cb);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_callback (self, cb);
 }
 
 
 /**
- * Visit operation called at end of callbacks.
- *
- * @param cb a callback
- */
-static void vala_code_visitor_real_visit_end_callback (ValaCodeVisitor* self, ValaCallback* cb)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_CALLBACK (cb));
-}
-
-
-void vala_code_visitor_visit_end_callback (ValaCodeVisitor* self, ValaCallback* cb)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_callback (self, cb);
-}
-
-
-/**
- * Visit operation called for Members.
+ * Visit operation called for members.
  *
  * @param m a member
  */
@@ -588,74 +428,38 @@ void vala_code_visitor_visit_field (ValaCodeVisitor* self, ValaField* f)
 
 
 /**
- * Visit operation called at beginning of methods.
+ * Visit operation called for methods.
  *
  * @param m a method
  */
-static void vala_code_visitor_real_visit_begin_method (ValaCodeVisitor* self, ValaMethod* m)
+static void vala_code_visitor_real_visit_method (ValaCodeVisitor* self, ValaMethod* m)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_METHOD (m));
 }
 
 
-void vala_code_visitor_visit_begin_method (ValaCodeVisitor* self, ValaMethod* m)
+void vala_code_visitor_visit_method (ValaCodeVisitor* self, ValaMethod* m)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_method (self, m);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_method (self, m);
 }
 
 
 /**
- * Visit operation called at end of methods.
+ * Visit operation called for creation methods.
  *
  * @param m a method
  */
-static void vala_code_visitor_real_visit_end_method (ValaCodeVisitor* self, ValaMethod* m)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_METHOD (m));
-}
-
-
-void vala_code_visitor_visit_end_method (ValaCodeVisitor* self, ValaMethod* m)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_method (self, m);
-}
-
-
-/**
- * Visit operation called at beginning of creation methods.
- *
- * @param m a method
- */
-static void vala_code_visitor_real_visit_begin_creation_method (ValaCodeVisitor* self, ValaCreationMethod* m)
+static void vala_code_visitor_real_visit_creation_method (ValaCodeVisitor* self, ValaCreationMethod* m)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_CREATION_METHOD (m));
 }
 
 
-void vala_code_visitor_visit_begin_creation_method (ValaCodeVisitor* self, ValaCreationMethod* m)
+void vala_code_visitor_visit_creation_method (ValaCodeVisitor* self, ValaCreationMethod* m)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_creation_method (self, m);
-}
-
-
-/**
- * Visit operation called at end of creation methods.
- *
- * @param m a method
- */
-static void vala_code_visitor_real_visit_end_creation_method (ValaCodeVisitor* self, ValaCreationMethod* m)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_CREATION_METHOD (m));
-}
-
-
-void vala_code_visitor_visit_end_creation_method (ValaCodeVisitor* self, ValaCreationMethod* m)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_creation_method (self, m);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_creation_method (self, m);
 }
 
 
@@ -678,182 +482,92 @@ void vala_code_visitor_visit_formal_parameter (ValaCodeVisitor* self, ValaFormal
 
 
 /**
- * Visit operation called at beginning of properties.
+ * Visit operation called for properties.
  *
  * @param prop a property
  */
-static void vala_code_visitor_real_visit_begin_property (ValaCodeVisitor* self, ValaProperty* prop)
+static void vala_code_visitor_real_visit_property (ValaCodeVisitor* self, ValaProperty* prop)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_PROPERTY (prop));
 }
 
 
-void vala_code_visitor_visit_begin_property (ValaCodeVisitor* self, ValaProperty* prop)
+void vala_code_visitor_visit_property (ValaCodeVisitor* self, ValaProperty* prop)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_property (self, prop);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_property (self, prop);
 }
 
 
 /**
- * Visit operation called at end of properties.
- *
- * @param prop a property
- */
-static void vala_code_visitor_real_visit_end_property (ValaCodeVisitor* self, ValaProperty* prop)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_PROPERTY (prop));
-}
-
-
-void vala_code_visitor_visit_end_property (ValaCodeVisitor* self, ValaProperty* prop)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_property (self, prop);
-}
-
-
-/**
- * Visit operation called at beginning of property accessors.
+ * Visit operation called for property accessors.
  *
  * @param acc a property accessor
  */
-static void vala_code_visitor_real_visit_begin_property_accessor (ValaCodeVisitor* self, ValaPropertyAccessor* acc)
+static void vala_code_visitor_real_visit_property_accessor (ValaCodeVisitor* self, ValaPropertyAccessor* acc)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (acc));
 }
 
 
-void vala_code_visitor_visit_begin_property_accessor (ValaCodeVisitor* self, ValaPropertyAccessor* acc)
+void vala_code_visitor_visit_property_accessor (ValaCodeVisitor* self, ValaPropertyAccessor* acc)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_property_accessor (self, acc);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_property_accessor (self, acc);
 }
 
 
 /**
- * Visit operation called at end of property accessors.
- *
- * @param acc a property accessor
- */
-static void vala_code_visitor_real_visit_end_property_accessor (ValaCodeVisitor* self, ValaPropertyAccessor* acc)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (acc));
-}
-
-
-void vala_code_visitor_visit_end_property_accessor (ValaCodeVisitor* self, ValaPropertyAccessor* acc)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_property_accessor (self, acc);
-}
-
-
-/**
- * Visit operation called at beginning of signals.
+ * Visit operation called for signals.
  *
  * @param sig a signal
  */
-static void vala_code_visitor_real_visit_begin_signal (ValaCodeVisitor* self, ValaSignal* sig)
+static void vala_code_visitor_real_visit_signal (ValaCodeVisitor* self, ValaSignal* sig)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_SIGNAL (sig));
 }
 
 
-void vala_code_visitor_visit_begin_signal (ValaCodeVisitor* self, ValaSignal* sig)
+void vala_code_visitor_visit_signal (ValaCodeVisitor* self, ValaSignal* sig)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_signal (self, sig);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_signal (self, sig);
 }
 
 
 /**
- * Visit operation called at end of signals.
- *
- * @param sig a signal
- */
-static void vala_code_visitor_real_visit_end_signal (ValaCodeVisitor* self, ValaSignal* sig)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_SIGNAL (sig));
-}
-
-
-void vala_code_visitor_visit_end_signal (ValaCodeVisitor* self, ValaSignal* sig)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_signal (self, sig);
-}
-
-
-/**
- * Visit operation called at beginning of constructors.
+ * Visit operation called for constructors.
  *
  * @param c a constructor
  */
-static void vala_code_visitor_real_visit_begin_constructor (ValaCodeVisitor* self, ValaConstructor* c)
+static void vala_code_visitor_real_visit_constructor (ValaCodeVisitor* self, ValaConstructor* c)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_CONSTRUCTOR (c));
 }
 
 
-void vala_code_visitor_visit_begin_constructor (ValaCodeVisitor* self, ValaConstructor* c)
+void vala_code_visitor_visit_constructor (ValaCodeVisitor* self, ValaConstructor* c)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_constructor (self, c);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_constructor (self, c);
 }
 
 
 /**
- * Visit operation called at end of constructors.
- *
- * @param c a constructor
- */
-static void vala_code_visitor_real_visit_end_constructor (ValaCodeVisitor* self, ValaConstructor* c)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_CONSTRUCTOR (c));
-}
-
-
-void vala_code_visitor_visit_end_constructor (ValaCodeVisitor* self, ValaConstructor* c)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_constructor (self, c);
-}
-
-
-/**
- * Visit operation called at beginning of destructors.
+ * Visit operation called for destructors.
  *
  * @param d a destructor
  */
-static void vala_code_visitor_real_visit_begin_destructor (ValaCodeVisitor* self, ValaDestructor* d)
+static void vala_code_visitor_real_visit_destructor (ValaCodeVisitor* self, ValaDestructor* d)
 {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
 	g_return_if_fail (VALA_IS_DESTRUCTOR (d));
 }
 
 
-void vala_code_visitor_visit_begin_destructor (ValaCodeVisitor* self, ValaDestructor* d)
+void vala_code_visitor_visit_destructor (ValaCodeVisitor* self, ValaDestructor* d)
 {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_begin_destructor (self, d);
-}
-
-
-/**
- * Visit operation called at end of destructors.
- *
- * @param d a destructor
- */
-static void vala_code_visitor_real_visit_end_destructor (ValaCodeVisitor* self, ValaDestructor* d)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_DESTRUCTOR (d));
-}
-
-
-void vala_code_visitor_visit_end_destructor (ValaCodeVisitor* self, ValaDestructor* d)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_end_destructor (self, d);
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_destructor (self, d);
 }
 
 
@@ -1776,6 +1490,24 @@ void vala_code_visitor_visit_end_object_creation_expression (ValaCodeVisitor* se
 }
 
 
+/**
+ * Visit operation called for sizeof expressions.
+ *
+ * @param expr a sizeof expression
+ */
+static void vala_code_visitor_real_visit_sizeof_expression (ValaCodeVisitor* self, ValaSizeofExpression* expr)
+{
+	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
+	g_return_if_fail (VALA_IS_SIZEOF_EXPRESSION (expr));
+}
+
+
+void vala_code_visitor_visit_sizeof_expression (ValaCodeVisitor* self, ValaSizeofExpression* expr)
+{
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_sizeof_expression (self, expr);
+}
+
+
 /**
  * Visit operation called for typeof expressions.
  *
@@ -2028,63 +1760,30 @@ void vala_code_visitor_visit_end_full_expression (ValaCodeVisitor* self, ValaExp
 }
 
 
-static void vala_code_visitor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
-	ValaCodeVisitor * self = VALA_CODE_VISITOR (object);
-	switch (property_id) {
-	}
-}
-
-
-static void vala_code_visitor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
-	ValaCodeVisitor * self = VALA_CODE_VISITOR (object);
-	switch (property_id) {
-	}
-}
-
-
 static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass)
 {
 	vala_code_visitor_parent_class = g_type_class_peek_parent (klass);
-	G_OBJECT_CLASS (klass)->get_property = vala_code_visitor_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_code_visitor_set_property;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_source_file = vala_code_visitor_real_visit_begin_source_file;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_source_file = vala_code_visitor_real_visit_end_source_file;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_namespace = vala_code_visitor_real_visit_begin_namespace;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_namespace = vala_code_visitor_real_visit_end_namespace;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_class = vala_code_visitor_real_visit_begin_class;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_class = vala_code_visitor_real_visit_end_class;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_struct = vala_code_visitor_real_visit_begin_struct;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_struct = vala_code_visitor_real_visit_end_struct;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_interface = vala_code_visitor_real_visit_begin_interface;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_interface = vala_code_visitor_real_visit_end_interface;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_enum = vala_code_visitor_real_visit_begin_enum;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_enum = vala_code_visitor_real_visit_end_enum;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_source_file = vala_code_visitor_real_visit_source_file;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_namespace = vala_code_visitor_real_visit_namespace;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_class = vala_code_visitor_real_visit_class;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_struct = vala_code_visitor_real_visit_struct;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_interface = vala_code_visitor_real_visit_interface;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_enum = vala_code_visitor_real_visit_enum;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum_value = vala_code_visitor_real_visit_enum_value;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_flags = vala_code_visitor_real_visit_begin_flags;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_flags = vala_code_visitor_real_visit_end_flags;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_flags = vala_code_visitor_real_visit_flags;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_flags_value = vala_code_visitor_real_visit_flags_value;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_callback = vala_code_visitor_real_visit_begin_callback;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_callback = vala_code_visitor_real_visit_end_callback;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_callback = vala_code_visitor_real_visit_callback;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_member = vala_code_visitor_real_visit_member;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_constant = vala_code_visitor_real_visit_constant;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_field = vala_code_visitor_real_visit_field;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_method = vala_code_visitor_real_visit_begin_method;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_method = vala_code_visitor_real_visit_end_method;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_creation_method = vala_code_visitor_real_visit_begin_creation_method;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_creation_method = vala_code_visitor_real_visit_end_creation_method;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_method = vala_code_visitor_real_visit_method;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_creation_method = vala_code_visitor_real_visit_creation_method;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_formal_parameter = vala_code_visitor_real_visit_formal_parameter;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_property = vala_code_visitor_real_visit_begin_property;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_property = vala_code_visitor_real_visit_end_property;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_property_accessor = vala_code_visitor_real_visit_begin_property_accessor;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_property_accessor = vala_code_visitor_real_visit_end_property_accessor;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_signal = vala_code_visitor_real_visit_begin_signal;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_signal = vala_code_visitor_real_visit_end_signal;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_constructor = vala_code_visitor_real_visit_begin_constructor;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_constructor = vala_code_visitor_real_visit_end_constructor;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_destructor = vala_code_visitor_real_visit_begin_destructor;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_end_destructor = vala_code_visitor_real_visit_end_destructor;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_property = vala_code_visitor_real_visit_property;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_property_accessor = vala_code_visitor_real_visit_property_accessor;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_signal = vala_code_visitor_real_visit_signal;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_constructor = vala_code_visitor_real_visit_constructor;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_destructor = vala_code_visitor_real_visit_destructor;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_named_argument = vala_code_visitor_real_visit_named_argument;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_type_parameter = vala_code_visitor_real_visit_type_parameter;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_namespace_reference = vala_code_visitor_real_visit_namespace_reference;
@@ -2136,6 +1835,7 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass)
 	VALA_CODE_VISITOR_CLASS (klass)->visit_postfix_expression = vala_code_visitor_real_visit_postfix_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_begin_object_creation_expression = vala_code_visitor_real_visit_begin_object_creation_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_end_object_creation_expression = vala_code_visitor_real_visit_end_object_creation_expression;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_sizeof_expression = vala_code_visitor_real_visit_sizeof_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_typeof_expression = vala_code_visitor_real_visit_typeof_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_unary_expression = vala_code_visitor_real_visit_unary_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_cast_expression = vala_code_visitor_real_visit_cast_expression;
