@@ -1,6 +1,6 @@
 /* valaconstructor.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -36,9 +36,10 @@ struct _ValaConstructorPrivate {
 enum  {
 	VALA_CONSTRUCTOR_DUMMY_PROPERTY,
 	VALA_CONSTRUCTOR_BODY,
-	VALA_CONSTRUCTOR_INSTANCE,
+	VALA_CONSTRUCTOR_INSTANCE
 };
 static void vala_constructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_constructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_constructor_parent_class = NULL;
 static void vala_constructor_dispose (GObject * obj);
 
@@ -51,24 +52,35 @@ static void vala_constructor_dispose (GObject * obj);
  */
 ValaConstructor* vala_constructor_new (ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaConstructor * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 1);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 1);
+	__params_it = __params;
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaConstructor * self = g_object_newv (VALA_TYPE_CONSTRUCTOR, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CONSTRUCTOR, __params_it - __params, __params);
 	return self;
 }
 
 
 static void vala_constructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaConstructor * self = VALA_CONSTRUCTOR (base);
+	ValaConstructor * self;
+	self = VALA_CONSTRUCTOR (base);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_visitor_visit_constructor (visitor, self);
+}
+
+
+static void vala_constructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
+{
+	ValaConstructor * self;
+	self = VALA_CONSTRUCTOR (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	vala_code_visitor_visit_begin_constructor (visitor, self);
 	if (vala_constructor_get_body (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_constructor_get_body (self)), visitor);
 	}
-	vala_code_visitor_visit_end_constructor (visitor, self);
 }
 
 
@@ -81,9 +93,11 @@ ValaStatement* vala_constructor_get_body (ValaConstructor* self)
 
 void vala_constructor_set_body (ValaConstructor* self, ValaStatement* value)
 {
+	ValaStatement* __temp2;
+	ValaStatement* __temp1;
 	g_return_if_fail (VALA_IS_CONSTRUCTOR (self));
-	ValaStatement* __temp2 = NULL;
-	ValaStatement* __temp1 = NULL;
+	__temp2 = NULL;
+	__temp1 = NULL;
 	self->priv->_body = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp2);
 }
 
@@ -104,7 +118,8 @@ void vala_constructor_set_instance (ValaConstructor* self, gboolean value)
 
 static void vala_constructor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaConstructor * self = VALA_CONSTRUCTOR (object);
+	ValaConstructor * self;
+	self = VALA_CONSTRUCTOR (object);
 	switch (property_id) {
 		case VALA_CONSTRUCTOR_BODY:
 		g_value_set_object (value, vala_constructor_get_body (self));
@@ -118,7 +133,8 @@ static void vala_constructor_get_property (GObject * object, guint property_id,
 
 static void vala_constructor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaConstructor * self = VALA_CONSTRUCTOR (object);
+	ValaConstructor * self;
+	self = VALA_CONSTRUCTOR (object);
 	switch (property_id) {
 		case VALA_CONSTRUCTOR_BODY:
 		vala_constructor_set_body (self, g_value_get_object (value));
@@ -138,6 +154,7 @@ static void vala_constructor_class_init (ValaConstructorClass * klass)
 	G_OBJECT_CLASS (klass)->set_property = vala_constructor_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_constructor_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_constructor_real_accept;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_constructor_real_accept_children;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTRUCTOR_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTRUCTOR_INSTANCE, g_param_spec_boolean ("instance", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -152,10 +169,11 @@ static void vala_constructor_init (ValaConstructor * self)
 
 static void vala_constructor_dispose (GObject * obj)
 {
-	ValaConstructor * self = VALA_CONSTRUCTOR (obj);
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
+	ValaConstructor * self;
 	ValaConstructorClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CONSTRUCTOR (obj);
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	klass = VALA_CONSTRUCTOR_CLASS (g_type_class_peek (VALA_TYPE_CONSTRUCTOR));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
