@@ -27,11 +27,8 @@
 #include <vala/valacodevisitor.h>
 #include <vala/valacontinuestatement.h>
 
-struct _ValaContinueStatementPrivate {
-};
-#define VALA_CONTINUE_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CONTINUE_STATEMENT, ValaContinueStatementPrivate))
 enum  {
-	VALA_CONTINUE_STATEMENT_DUMMY_PROPERTY,
+	VALA_CONTINUE_STATEMENT_DUMMY_PROPERTY
 };
 static void vala_continue_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_continue_statement_parent_class = NULL;
@@ -45,44 +42,30 @@ static gpointer vala_continue_statement_parent_class = NULL;
  */
 ValaContinueStatement* vala_continue_statement_new (ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaContinueStatement * self;
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 1);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 1);
+	__params_it = __params;
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaContinueStatement * self = g_object_newv (VALA_TYPE_CONTINUE_STATEMENT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CONTINUE_STATEMENT, __params_it - __params, __params);
 	return self;
 }
 
 
 static void vala_continue_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaContinueStatement * self = VALA_CONTINUE_STATEMENT (base);
+	ValaContinueStatement * self;
+	self = VALA_CONTINUE_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_continue_statement (visitor, self);
 }
 
 
-static void vala_continue_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
-	ValaContinueStatement * self = VALA_CONTINUE_STATEMENT (object);
-	switch (property_id) {
-	}
-}
-
-
-static void vala_continue_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
-	ValaContinueStatement * self = VALA_CONTINUE_STATEMENT (object);
-	switch (property_id) {
-	}
-}
-
-
 static void vala_continue_statement_class_init (ValaContinueStatementClass * klass)
 {
 	vala_continue_statement_parent_class = g_type_class_peek_parent (klass);
-	G_OBJECT_CLASS (klass)->get_property = vala_continue_statement_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_continue_statement_set_property;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_continue_statement_real_accept;
 }
 
