@@ -36,7 +36,7 @@ struct _ValaInstanceCastPrivate {
 enum  {
 	VALA_INSTANCE_CAST_DUMMY_PROPERTY,
 	VALA_INSTANCE_CAST_TYPE_REFERENCE,
-	VALA_INSTANCE_CAST_INNER,
+	VALA_INSTANCE_CAST_INNER
 };
 static GObject * vala_instance_cast_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_instance_cast_parent_class = NULL;
@@ -52,13 +52,16 @@ static void vala_instance_cast_dispose (GObject * obj);
  */
 ValaInstanceCast* vala_instance_cast_new (ValaCCodeExpression* expr, ValaDataType* type)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaInstanceCast * self;
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (type), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
 	(__params_it->name = "type-reference", g_value_init (&__params_it->value, VALA_TYPE_DATA_TYPE), g_value_set_object (&__params_it->value, type), __params_it++);
-	ValaInstanceCast * self = g_object_newv (VALA_TYPE_INSTANCE_CAST, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_INSTANCE_CAST, __params_it - __params, __params);
 	return self;
 }
 
@@ -72,8 +75,9 @@ ValaDataType* vala_instance_cast_get_type_reference (ValaInstanceCast* self)
 
 void vala_instance_cast_set_type_reference (ValaInstanceCast* self, ValaDataType* value)
 {
+	ValaDataType* __temp1;
 	g_return_if_fail (VALA_IS_INSTANCE_CAST (self));
-	ValaDataType* __temp1 = NULL;
+	__temp1 = NULL;
 	self->priv->_type_reference = (__temp1 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp1);
 }
 
@@ -87,8 +91,9 @@ ValaCCodeExpression* vala_instance_cast_get_inner (ValaInstanceCast* self)
 
 void vala_instance_cast_set_inner (ValaInstanceCast* self, ValaCCodeExpression* value)
 {
+	ValaCCodeExpression* __temp3;
 	g_return_if_fail (VALA_IS_INSTANCE_CAST (self));
-	ValaCCodeExpression* __temp3 = NULL;
+	__temp3 = NULL;
 	self->priv->_inner = (__temp3 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp3);
 }
 
@@ -98,12 +103,14 @@ static GObject * vala_instance_cast_constructor (GType type, guint n_construct_p
 	GObject * obj;
 	ValaInstanceCastClass * klass;
 	GObjectClass * parent_class;
+	ValaInstanceCast * self;
 	klass = VALA_INSTANCE_CAST_CLASS (g_type_class_peek (VALA_TYPE_INSTANCE_CAST));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
-	ValaInstanceCast * self = VALA_INSTANCE_CAST (obj);
+	self = VALA_INSTANCE_CAST (obj);
 	{
-		ValaCCodeIdentifier* __temp4 = NULL;
+		ValaCCodeIdentifier* __temp4;
+		__temp4 = NULL;
 		(vala_ccode_function_call_set_call (VALA_CCODE_FUNCTION_CALL (self), VALA_CCODE_EXPRESSION ((__temp4 = vala_ccode_identifier_new (vala_data_type_get_upper_case_cname (vala_instance_cast_get_type_reference (self), NULL))))), vala_ccode_function_call_get_call (VALA_CCODE_FUNCTION_CALL (self)));
 		(__temp4 == NULL ? NULL : (__temp4 = (g_object_unref (__temp4), NULL)));
 		vala_ccode_function_call_add_argument (VALA_CCODE_FUNCTION_CALL (self), VALA_CCODE_EXPRESSION (vala_instance_cast_get_inner (self)));
@@ -114,7 +121,8 @@ static GObject * vala_instance_cast_constructor (GType type, guint n_construct_p
 
 static void vala_instance_cast_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaInstanceCast * self = VALA_INSTANCE_CAST (object);
+	ValaInstanceCast * self;
+	self = VALA_INSTANCE_CAST (object);
 	switch (property_id) {
 		case VALA_INSTANCE_CAST_TYPE_REFERENCE:
 		g_value_set_object (value, vala_instance_cast_get_type_reference (self));
@@ -128,7 +136,8 @@ static void vala_instance_cast_get_property (GObject * object, guint property_id
 
 static void vala_instance_cast_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaInstanceCast * self = VALA_INSTANCE_CAST (object);
+	ValaInstanceCast * self;
+	self = VALA_INSTANCE_CAST (object);
 	switch (property_id) {
 		case VALA_INSTANCE_CAST_TYPE_REFERENCE:
 		vala_instance_cast_set_type_reference (self, g_value_get_object (value));
@@ -161,11 +170,12 @@ static void vala_instance_cast_init (ValaInstanceCast * self)
 
 static void vala_instance_cast_dispose (GObject * obj)
 {
-	ValaInstanceCast * self = VALA_INSTANCE_CAST (obj);
-	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
+	ValaInstanceCast * self;
 	ValaInstanceCastClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_INSTANCE_CAST (obj);
+	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
+	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
 	klass = VALA_INSTANCE_CAST_CLASS (g_type_class_peek (VALA_TYPE_INSTANCE_CAST));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
