@@ -1,6 +1,6 @@
 /* valainvocationexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,9 +22,11 @@
 
 #ifndef __VALAINVOCATIONEXPRESSION_H__
 #define __VALAINVOCATIONEXPRESSION_H__
+typedef struct _ValaInvocationExpressionPrivate ValaInvocationExpressionPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
+#include <ccode/valaccodeexpression.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
 
@@ -38,7 +40,6 @@ G_BEGIN_DECLS
 #define VALA_IS_INVOCATION_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_INVOCATION_EXPRESSION))
 #define VALA_INVOCATION_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_INVOCATION_EXPRESSION, ValaInvocationExpressionClass))
 
-typedef struct _ValaInvocationExpressionPrivate ValaInvocationExpressionPrivate;
 
 /**
  * Represents an invocation expression in the source code.
@@ -55,6 +56,8 @@ struct _ValaInvocationExpressionClass {
 ValaInvocationExpression* vala_invocation_expression_new (ValaExpression* _call, ValaSourceReference* source);
 void vala_invocation_expression_add_argument (ValaInvocationExpression* self, ValaExpression* arg);
 GList* vala_invocation_expression_get_argument_list (ValaInvocationExpression* self);
+void vala_invocation_expression_append_array_size (ValaInvocationExpression* self, ValaCCodeExpression* size);
+GList* vala_invocation_expression_get_array_sizes (ValaInvocationExpression* self);
 ValaExpression* vala_invocation_expression_get_call (ValaInvocationExpression* self);
 void vala_invocation_expression_set_call (ValaInvocationExpression* self, ValaExpression* value);
 GType vala_invocation_expression_get_type ();
