@@ -37,7 +37,7 @@ struct _ValaMemberAccessPrivate {
 enum  {
 	VALA_MEMBER_ACCESS_DUMMY_PROPERTY,
 	VALA_MEMBER_ACCESS_INNER,
-	VALA_MEMBER_ACCESS_MEMBER_NAME,
+	VALA_MEMBER_ACCESS_MEMBER_NAME
 };
 static void vala_member_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_member_access_real_to_string (ValaCodeNode* base);
@@ -56,28 +56,34 @@ static void vala_member_access_dispose (GObject * obj);
  */
 ValaMemberAccess* vala_member_access_new (ValaExpression* _inner, const char* member, ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaMemberAccess * self;
 	g_return_val_if_fail (_inner == NULL || VALA_IS_EXPRESSION (_inner), NULL);
 	g_return_val_if_fail (member != NULL, NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 3);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, _inner), __params_it++);
 	(__params_it->name = "member-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, member), __params_it++);
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaMemberAccess * self = g_object_newv (VALA_TYPE_MEMBER_ACCESS, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_MEMBER_ACCESS, __params_it - __params, __params);
 	return self;
 }
 
 
 ValaMemberAccess* vala_member_access_new_simple (const char* member, ValaSourceReference* source)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaMemberAccess * self;
 	g_return_val_if_fail (member != NULL, NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "member-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, member), __params_it++);
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	ValaMemberAccess * self = g_object_newv (VALA_TYPE_MEMBER_ACCESS, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_MEMBER_ACCESS, __params_it - __params, __params);
 	return self;
 }
 
@@ -109,17 +115,20 @@ GList* vala_member_access_get_type_arguments (ValaMemberAccess* self)
 
 static void vala_member_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaMemberAccess * self = VALA_MEMBER_ACCESS (base);
+	ValaMemberAccess * self;
+	self = VALA_MEMBER_ACCESS (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_member_access_get_inner (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_member_access_get_inner (self)), visitor);
 	}
 	{
-		GList* __temp1 = NULL;
-		__temp1 = self->priv->type_argument_list;
+		GList* __temp1;
 		GList* type_arg_it;
+		__temp1 = NULL;
+		__temp1 = self->priv->type_argument_list;
 		for (type_arg_it = __temp1; type_arg_it != NULL; type_arg_it = type_arg_it->next) {
-			ValaTypeReference* type_arg = type_arg_it->data;
+			ValaTypeReference* type_arg;
+			type_arg = type_arg_it->data;
 			{
 				vala_code_node_accept (VALA_CODE_NODE (type_arg), visitor);
 			}
@@ -131,12 +140,15 @@ static void vala_member_access_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 
 static char* vala_member_access_real_to_string (ValaCodeNode* base)
 {
-	ValaMemberAccess * self = VALA_MEMBER_ACCESS (base);
+	ValaMemberAccess * self;
+	self = VALA_MEMBER_ACCESS (base);
 	if (vala_member_access_get_inner (self) == NULL) {
 		return g_strdup (vala_member_access_get_member_name (self));
 	} else {
-		char* __temp3 = NULL;
-		char* __temp4 = NULL;
+		char* __temp3;
+		char* __temp4;
+		__temp3 = NULL;
+		__temp4 = NULL;
 		return (__temp4 = g_strdup_printf ("%s.%s", (__temp3 = vala_code_node_to_string (VALA_CODE_NODE (vala_member_access_get_inner (self)))), vala_member_access_get_member_name (self)), (__temp3 = (g_free (__temp3), NULL)), __temp4);
 	}
 }
@@ -144,7 +156,8 @@ static char* vala_member_access_real_to_string (ValaCodeNode* base)
 
 static void vala_member_access_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
-	ValaMemberAccess * self = VALA_MEMBER_ACCESS (base);
+	ValaMemberAccess * self;
+	self = VALA_MEMBER_ACCESS (base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_member_access_get_inner (self)) == old_node) {
@@ -162,9 +175,11 @@ ValaExpression* vala_member_access_get_inner (ValaMemberAccess* self)
 
 void vala_member_access_set_inner (ValaMemberAccess* self, ValaExpression* value)
 {
+	ValaExpression* __temp8;
+	ValaExpression* __temp7;
 	g_return_if_fail (VALA_IS_MEMBER_ACCESS (self));
-	ValaExpression* __temp8 = NULL;
-	ValaExpression* __temp7 = NULL;
+	__temp8 = NULL;
+	__temp7 = NULL;
 	self->priv->_inner = (__temp8 = (__temp7 = value, (__temp7 == NULL ? NULL : g_object_ref (__temp7))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp8);
 	if (self->priv->_inner != NULL) {
 		(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_inner)));
@@ -181,15 +196,17 @@ char* vala_member_access_get_member_name (ValaMemberAccess* self)
 
 void vala_member_access_set_member_name (ValaMemberAccess* self, const char* value)
 {
+	char* __temp10;
 	g_return_if_fail (VALA_IS_MEMBER_ACCESS (self));
-	char* __temp10 = NULL;
+	__temp10 = NULL;
 	self->priv->_member_name = (__temp10 = g_strdup (value), (self->priv->_member_name = (g_free (self->priv->_member_name), NULL)), __temp10);
 }
 
 
 static void vala_member_access_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaMemberAccess * self = VALA_MEMBER_ACCESS (object);
+	ValaMemberAccess * self;
+	self = VALA_MEMBER_ACCESS (object);
 	switch (property_id) {
 		case VALA_MEMBER_ACCESS_INNER:
 		g_value_set_object (value, vala_member_access_get_inner (self));
@@ -203,7 +220,8 @@ static void vala_member_access_get_property (GObject * object, guint property_id
 
 static void vala_member_access_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaMemberAccess * self = VALA_MEMBER_ACCESS (object);
+	ValaMemberAccess * self;
+	self = VALA_MEMBER_ACCESS (object);
 	switch (property_id) {
 		case VALA_MEMBER_ACCESS_INNER:
 		vala_member_access_set_inner (self, g_value_get_object (value));
@@ -238,12 +256,13 @@ static void vala_member_access_init (ValaMemberAccess * self)
 
 static void vala_member_access_dispose (GObject * obj)
 {
-	ValaMemberAccess * self = VALA_MEMBER_ACCESS (obj);
+	ValaMemberAccess * self;
+	ValaMemberAccessClass * klass;
+	GObjectClass * parent_class;
+	self = VALA_MEMBER_ACCESS (obj);
 	(self->priv->_member_name = (g_free (self->priv->_member_name), NULL));
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
 	(self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (g_list_foreach (self->priv->type_argument_list, (GFunc) g_object_unref, NULL), g_list_free (self->priv->type_argument_list), NULL)));
-	ValaMemberAccessClass * klass;
-	GObjectClass * parent_class;
 	klass = VALA_MEMBER_ACCESS_CLASS (g_type_class_peek (VALA_TYPE_MEMBER_ACCESS));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
