@@ -1,6 +1,6 @@
 /* valasourcefile.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,6 +22,7 @@
 
 #ifndef __VALASOURCEFILE_H__
 #define __VALASOURCEFILE_H__
+typedef struct _ValaSourceFilePrivate ValaSourceFilePrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -40,7 +41,6 @@ G_BEGIN_DECLS
 #define VALA_IS_SOURCE_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SOURCE_FILE))
 #define VALA_SOURCE_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SOURCE_FILE, ValaSourceFileClass))
 
-typedef struct _ValaSourceFilePrivate ValaSourceFilePrivate;
 
 /**
  * Represents a Vala source or VAPI package file.
@@ -55,7 +55,7 @@ struct _ValaSourceFileClass {
 typedef enum  {
 	VALA_SOURCE_FILE_DEPENDENCY_TYPE_HEADER_FULL,
 	VALA_SOURCE_FILE_DEPENDENCY_TYPE_HEADER_SHALLOW,
-	VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE,
+	VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE
 } ValaSourceFileDependencyType;
 
 ValaSourceFile* vala_source_file_new (ValaCodeContext* _context, const char* _filename, gboolean _pkg);
@@ -65,6 +65,7 @@ void vala_source_file_add_namespace (ValaSourceFile* self, ValaNamespace* ns);
 ValaNamespace* vala_source_file_get_global_namespace (ValaSourceFile* self);
 GList* vala_source_file_get_namespaces (ValaSourceFile* self);
 void vala_source_file_accept (ValaSourceFile* self, ValaCodeVisitor* visitor);
+void vala_source_file_accept_children (ValaSourceFile* self, ValaCodeVisitor* visitor);
 char* vala_source_file_get_cheader_filename (ValaSourceFile* self);
 char* vala_source_file_get_csource_filename (ValaSourceFile* self);
 char* vala_source_file_get_cinclude_filename (ValaSourceFile* self);
