@@ -34,7 +34,7 @@ struct _ValaThrowStatementPrivate {
 #define VALA_THROW_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_THROW_STATEMENT, ValaThrowStatementPrivate))
 enum  {
 	VALA_THROW_STATEMENT_DUMMY_PROPERTY,
-	VALA_THROW_STATEMENT_ERROR_EXPRESSION,
+	VALA_THROW_STATEMENT_ERROR_EXPRESSION
 };
 static void vala_throw_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_throw_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
@@ -51,20 +51,24 @@ static void vala_throw_statement_dispose (GObject * obj);
  */
 ValaThrowStatement* vala_throw_statement_new (ValaExpression* error_expression, ValaSourceReference* source_reference)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaThrowStatement * self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (error_expression), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "error-expression", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, error_expression), __params_it++);
 	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source_reference), __params_it++);
-	ValaThrowStatement * self = g_object_newv (VALA_TYPE_THROW_STATEMENT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_THROW_STATEMENT, __params_it - __params, __params);
 	return self;
 }
 
 
 static void vala_throw_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
-	ValaThrowStatement * self = VALA_THROW_STATEMENT (base);
+	ValaThrowStatement * self;
+	self = VALA_THROW_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_begin_throw_statement (visitor, self);
 	if (vala_throw_statement_get_error_expression (self) != NULL) {
@@ -77,7 +81,8 @@ static void vala_throw_statement_real_accept (ValaCodeNode* base, ValaCodeVisito
 
 static void vala_throw_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
-	ValaThrowStatement * self = VALA_THROW_STATEMENT (base);
+	ValaThrowStatement * self;
+	self = VALA_THROW_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_throw_statement_get_error_expression (self)) == old_node) {
@@ -95,9 +100,11 @@ ValaExpression* vala_throw_statement_get_error_expression (ValaThrowStatement* s
 
 void vala_throw_statement_set_error_expression (ValaThrowStatement* self, ValaExpression* value)
 {
+	ValaExpression* __temp2;
+	ValaExpression* __temp1;
 	g_return_if_fail (VALA_IS_THROW_STATEMENT (self));
-	ValaExpression* __temp2 = NULL;
-	ValaExpression* __temp1 = NULL;
+	__temp2 = NULL;
+	__temp1 = NULL;
 	self->priv->_error_expression = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_error_expression == NULL ? NULL : (self->priv->_error_expression = (g_object_unref (self->priv->_error_expression), NULL))), __temp2);
 	if (self->priv->_error_expression != NULL) {
 		(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_error_expression), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_error_expression)));
@@ -107,7 +114,8 @@ void vala_throw_statement_set_error_expression (ValaThrowStatement* self, ValaEx
 
 static void vala_throw_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaThrowStatement * self = VALA_THROW_STATEMENT (object);
+	ValaThrowStatement * self;
+	self = VALA_THROW_STATEMENT (object);
 	switch (property_id) {
 		case VALA_THROW_STATEMENT_ERROR_EXPRESSION:
 		g_value_set_object (value, vala_throw_statement_get_error_expression (self));
@@ -118,7 +126,8 @@ static void vala_throw_statement_get_property (GObject * object, guint property_
 
 static void vala_throw_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaThrowStatement * self = VALA_THROW_STATEMENT (object);
+	ValaThrowStatement * self;
+	self = VALA_THROW_STATEMENT (object);
 	switch (property_id) {
 		case VALA_THROW_STATEMENT_ERROR_EXPRESSION:
 		vala_throw_statement_set_error_expression (self, g_value_get_object (value));
@@ -148,10 +157,11 @@ static void vala_throw_statement_init (ValaThrowStatement * self)
 
 static void vala_throw_statement_dispose (GObject * obj)
 {
-	ValaThrowStatement * self = VALA_THROW_STATEMENT (obj);
-	(self->priv->_error_expression == NULL ? NULL : (self->priv->_error_expression = (g_object_unref (self->priv->_error_expression), NULL)));
+	ValaThrowStatement * self;
 	ValaThrowStatementClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_THROW_STATEMENT (obj);
+	(self->priv->_error_expression == NULL ? NULL : (self->priv->_error_expression = (g_object_unref (self->priv->_error_expression), NULL)));
 	klass = VALA_THROW_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_THROW_STATEMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
